@@ -6,7 +6,9 @@ import time
 import logging
 import wsaccel
 import sys
+import ScratchEncoder
 ws = websocket.WebSocket()
+encoder = ScratchEncoder()
 
 
 class s2py():
@@ -57,6 +59,12 @@ class s2py():
                 "referer": "",
             }
 
+    def decode(self, text):
+        encoder.decode(text)
+    
+    def encode(self, text):
+        encoder.encode(text)
+    
     def getStats(self, id, stat):
         if stat == "loves" or stat == "faves" or stat == "views" or stat == "remixes":
             if stat == "loves":
